@@ -34,7 +34,8 @@
 #include <qpainter.h>
 #include <qpen.h>
 #include <qcolordialog.h>
-  
+#include <kiconloader.h>
+
 KonfiguratorExtension::KonfiguratorExtension( QObject *obj, QString cfgClass, QString cfgName, bool rst) :
       QObject(), objectPtr( obj ), applyConnected( false ), setDefaultsConnected( false ),
       changed( false ), restartNeeded( rst ), configClass( cfgClass ), configName( cfgName )
@@ -46,12 +47,12 @@ void KonfiguratorExtension::connectNotify( const char *signal )
   QString signalString    = QString( signal ).replace( " ", "" );
   QString applyString     = QString( SIGNAL( applyManually(QObject *,QString, QString) ) ).replace( " ", "" );
   QString defaultsString  = QString( SIGNAL( setDefaultsManually(QObject *) ) ).replace( " ", "" );
-  
+
   if( signalString == applyString )
     applyConnected = true;
   else if ( signalString == defaultsString )
     setDefaultsConnected = true;
-    
+
   QObject::connectNotify( signal );
 }
 
@@ -59,7 +60,7 @@ bool KonfiguratorExtension::apply()
 {
   if( !changed )
     return false;
-    
+
   if( applyConnected )
     emit applyManually( objectPtr, configClass, configName );
   else
@@ -95,10 +96,10 @@ KonfiguratorCheckBox::KonfiguratorCheckBox( QString cls, QString name, bool dflt
     defaultValue( dflt )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst );
-  connect( ext, SIGNAL( applyAuto(QObject *,QString, QString) ), this, SLOT( slotApply(QObject *,QString, QString) ) );  
+  connect( ext, SIGNAL( applyAuto(QObject *,QString, QString) ), this, SLOT( slotApply(QObject *,QString, QString) ) );
   connect( ext, SIGNAL( setDefaultsAuto(QObject *) ), this, SLOT( slotSetDefaults(QObject *) ) );
   connect( ext, SIGNAL( setInitialValue(QObject *) ), this, SLOT( loadInitialValue() ) );
- 
+
   connect( this, SIGNAL( stateChanged( int ) ), ext, SLOT( setChanged() ) );
   loadInitialValue();
 }
@@ -143,7 +144,7 @@ KonfiguratorSpinBox::KonfiguratorSpinBox( QString cls, QString name, int dflt, i
 
   setMinValue( min );
   setMaxValue( max );
-  
+
   loadInitialValue();
 }
 
@@ -194,7 +195,7 @@ KonfiguratorCheckBox * KonfiguratorCheckBoxGroup::find( QString name )
       return checkBox;
     checkBox = checkBoxList.next();
   }
-  
+
   return 0;
 }
 
@@ -217,13 +218,14 @@ KonfiguratorRadioButtons::~KonfiguratorRadioButtons()
   delete ext;
 }
 
-void KonfiguratorRadioButtons::addRadioButton( QRadioButton *radioWidget, QString value )
+void KonfiguratorRadioButtons::addRadioButton( QRadioButton *radioWidget, QString name, QString value )
 {
   radioButtons.append( radioWidget );
+  radioNames.push_back( name );
   radioValues.push_back( value );
 
   connect( radioWidget, SIGNAL( stateChanged(int) ), ext, SLOT( setChanged() ) );
-}                                                       
+}
 
 QRadioButton * KonfiguratorRadioButtons::find( int index )
 {
@@ -232,16 +234,11 @@ QRadioButton * KonfiguratorRadioButtons::find( int index )
 
 QRadioButton * KonfiguratorRadioButtons::find( QString name )
 {
-  QRadioButton *radioButton = radioButtons.first();
+  int index = radioNames.findIndex( name );
+  if( index == -1 )
+    return 0;
 
-  while( radioButton )
-  {
-    if( radioButton->text() == name )
-      return radioButton;
-    radioButton = radioButtons.next();
-  }
-
-  return 0;
+  return radioButtons.at( index );
 }
 
 void KonfiguratorRadioButtons::selectButton( QString value )
@@ -343,78 +340,6 @@ void KonfiguratorEditBox::slotSetDefaults(QObject *)
 // KonfiguratorURLRequester class
 ///////////////////////////////
 
-static const char* const image0_data[] = {
-"16 16 53 1",
-". c None",
-"# c #000000",
-"R c #080808",
-"Q c #101010",
-"Y c #181c18",
-"K c #202020",
-"w c #313031",
-"X c #313431",
-"W c #414041",
-"V c #414441",
-"g c #4a3018",
-"E c #4a484a",
-"U c #4a4c4a",
-"l c #524c4a",
-"h c #52504a",
-"j c #525052",
-"i c #5a5952",
-"J c #6a6962",
-"P c #6a6d6a",
-"T c #8b8d8b",
-"D c #949594",
-"S c #9c999c",
-"O c #9c9d9c",
-"C c #a4a19c",
-"M c #a4a1a4",
-"N c #a4a5a4",
-"I c #acaaac",
-"B c #acaeac",
-"F c #b47d41",
-"v c #b4b2b4",
-"u c #b4b6b4",
-"A c #bdbabd",
-"t c #bdbebd",
-"k c #c5854a",
-"H c #c5c2c5",
-"s c #c5c6c5",
-"r c #cdcacd",
-"L c #cdcecd",
-"z c #d5d2d5",
-"q c #d5d6d5",
-"x c #dedade",
-"p c #dedede",
-"a c #e6a562",
-"G c #e6e2e6",
-"o c #e6e6e6",
-"y c #eeeae6",
-"n c #eeeeee",
-"m c #f6f6f6",
-"e c #ffae62",
-"d c #ffc283",
-"c c #ffc683",
-"f c #ffca8b",
-"b c #ffd29c",
-"......####......",
-".....##.####.#..",
-"....#.....####..",
-"...........###..",
-"..........####..",
-".####...........",
-"#abca#######....",
-"#bcdeeeeeeee#...",
-"#fdghhhihhjjh###",
-"#dklmmnopqrstuvw",
-"#dgxpyopzsABCDE.",
-"#FhxxGpqrHuICJK.",
-"#gLrqqzLHABMDE..",
-"#jLtssHtuBNOPQ..",
-"RtNIBBINMSDTE...",
-"KEEUUUEEVWWXY..."};
-
 KonfiguratorURLRequester::KonfiguratorURLRequester( QString cls, QString name, QString dflt,
     QWidget *parent, const char *widgetName, bool rst ) : KURLRequester( parent, widgetName ),
     defaultValue( dflt )
@@ -426,9 +351,7 @@ KonfiguratorURLRequester::KonfiguratorURLRequester( QString cls, QString name, Q
 
   connect( this, SIGNAL( textChanged(const QString &) ), ext, SLOT( setChanged() ) );
 
-  QPixmap pixMap( (const char **)image0_data );
-  button()->setIconSet( QIconSet() );
-  button()->setPixmap( pixMap );
+  button()->setIconSet( SmallIcon( "fileopen" ) );
   loadInitialValue();
 }
 
@@ -471,13 +394,11 @@ KonfiguratorFontChooser::KonfiguratorFontChooser( QString cls, QString name, QFo
   pLabel = new QLabel( this );
   pLabel->setMinimumWidth( 150 );
   pToolButton = new QToolButton( this );
-  
+
   connect( pToolButton, SIGNAL( clicked() ), this, SLOT( slotBrowseFont() ) );
 
-  QPixmap pixMap( (const char **)image0_data );
-  pToolButton->setText( "" );
-  pToolButton->setPixmap( pixMap );
-  
+  pToolButton->setIconSet( SmallIcon( "fileopen" ) );
+
   loadInitialValue();
 }
 
@@ -530,13 +451,13 @@ KonfiguratorComboBox::KonfiguratorComboBox( QString cls, QString name, QString d
     defaultValue( dflt ), listLen( listInLen )
 {
   list = new KONFIGURATOR_NAME_VALUE_PAIR[ listInLen ];
-  
+
   for( int i=0; i != listLen; i++ )
   {
     list[i] = listIn[i];
     insertItem( list[i].text );
   }
-    
+
   ext = new KonfiguratorExtension( this, cls, name, rst );
   connect( ext, SIGNAL( applyAuto(QObject *,QString, QString) ), this, SLOT( slotApply(QObject *,QString, QString) ) );
   connect( ext, SIGNAL( setDefaultsAuto(QObject *) ), this, SLOT( slotSetDefaults(QObject *) ) );
@@ -601,7 +522,7 @@ KonfiguratorColorChooser::KonfiguratorColorChooser( QString cls, QString name, Q
     defaultValue( dflt ), disableColorChooser( true )
 {
   ext = new KonfiguratorExtension( this, cls, name, rst );
-  
+
   connect( ext, SIGNAL( applyAuto(QObject *,QString, QString) ), this, SLOT( slotApply(QObject *,QString, QString) ) );
   connect( ext, SIGNAL( setDefaultsAuto(QObject *) ), this, SLOT( slotSetDefaults(QObject *) ) );
   connect( ext, SIGNAL( setInitialValue(QObject *) ), this, SLOT( loadInitialValue() ) );
@@ -614,7 +535,7 @@ KonfiguratorColorChooser::KonfiguratorColorChooser( QString cls, QString name, Q
     additionalColors.push_back( addColPtr[i] );
     addColor( addColPtr[i].name, addColPtr[i].color );
   }
-  
+
   addColor( i18n("Red" ),           Qt::red );
   addColor( i18n("Green" ),         Qt::green );
   addColor( i18n("Blue" ),          Qt::blue );
@@ -652,7 +573,7 @@ QPixmap KonfiguratorColorChooser::createPixmap( QColor color )
   QPixmap pixmap( rect.width(), rect.height() );
 
   pen.setColor( Qt::black );
-  
+
   painter.begin( &pixmap );
   QBrush brush( color );
   painter.fillRect( rect, brush );
@@ -672,48 +593,10 @@ void KonfiguratorColorChooser::addColor( QString text, QColor color )
 
 void KonfiguratorColorChooser::loadInitialValue()
 {
-  disableColorChooser = true;
-  
   krConfig->setGroup( ext->getCfgClass() );
   QString selected = krConfig->readEntry( ext->getCfgName(), "" );
-  if( selected.isEmpty() )
-  {
-    setCurrentItem( 1 );
-    customValue = defaultValue;
-  }
-  else
-  {
-    bool found = false;
-    
-    for( unsigned j=0; j != additionalColors.size(); j++ )
-      if( additionalColors[j].value == selected )
-      {
-        setCurrentItem( 2 + j );
-        found = true;
-        break;
-      }
-
-    if( ! found )
-    {
-      QColor color = krConfig->readColorEntry( ext->getCfgName(), &defaultValue );
-      customValue = color;
-
-      setCurrentItem( 0 );
-      for( unsigned i= 2+additionalColors.size(); i != palette.size(); i++ )
-        if( palette[i] == color )
-        {
-          setCurrentItem( i );
-          break;
-        }
-    }
-  }
-
-  palette[0] = customValue;
-  changeItem( createPixmap( customValue ), text( 0 ), 0 );
-      
+  setValue( selected );
   ext->setChanged( false );
-  emit colorChanged();
-  disableColorChooser = false;
 }
 
 void KonfiguratorColorChooser::setDefaultColor( QColor dflt )
@@ -747,14 +630,65 @@ void KonfiguratorColorChooser::setDefaultText( QString text )
 void KonfiguratorColorChooser::slotApply(QObject *,QString cls, QString name)
 {
   krConfig->setGroup( cls );
-  
+  krConfig->writeEntry( name, getValue() );
+}
+
+void KonfiguratorColorChooser::setValue( QString value )
+{
+  disableColorChooser = true;
+
+  if( value.isEmpty() )
+  {
+    setCurrentItem( 1 );
+    customValue = defaultValue;
+  }
+  else
+  {
+    bool found = false;
+
+    for( unsigned j=0; j != additionalColors.size(); j++ )
+      if( additionalColors[j].value == value )
+      {
+        setCurrentItem( 2 + j );
+        found = true;
+        break;
+      }
+
+    if( ! found )
+    {
+      krConfig->setGroup( ext->getCfgClass() );
+      krConfig->writeEntry( "TmpColor", value );
+      QColor color = krConfig->readColorEntry( "TmpColor", &defaultValue );
+      customValue = color;
+      krConfig->deleteEntry( "TmpColor" );
+
+      setCurrentItem( 0 );
+      for( unsigned i= 2+additionalColors.size(); i != palette.size(); i++ )
+        if( palette[i] == color )
+        {
+          setCurrentItem( i );
+          break;
+        }
+    }
+  }
+
+  palette[0] = customValue;
+  changeItem( createPixmap( customValue ), text( 0 ), 0 );
+
+  ext->setChanged();
+  emit colorChanged();
+  disableColorChooser = false;
+}
+
+QString KonfiguratorColorChooser::getValue()
+{
   QColor color = palette[ currentItem() ];
   if( currentItem() == 1 )    /* it's the default value? */
-    krConfig->writeEntry( name, "" );   /* set nothing */
+    return "";
   else if( currentItem() >= 2 && (unsigned)currentItem() < 2 + additionalColors.size() )
-    krConfig->writeEntry( name, additionalColors[ currentItem() - 2 ].value );
+    return additionalColors[ currentItem() - 2 ].value;
   else
-    krConfig->writeEntry( name, color );
+    return QString( "%1,%2,%3" ).arg( color.red() ).arg( color.green() ).arg( color.blue() );
 }
 
 void KonfiguratorColorChooser::slotSetDefaults(QObject *)
