@@ -31,6 +31,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "krdetailedviewitem.h"
 #include "krcolorcache.h"
 #include "krselectionmode.h"
+#include "../krusader.h"
 #include "../kicons.h"
 #include "../defaults.h"
 #include "../krusaderview.h"
@@ -38,18 +39,20 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../VFS/krpermhandler.h"
 #include "../GUI/kcmdline.h"
 #include "../Dialogs/krspecialwidgets.h"
+#include "../panelmanager.h"
 #include "listpanel.h"
 #include "panelfunc.h"
 #include <qlayout.h>
 #include <qdir.h>
 #include <qwhatsthis.h>
 #include <qheader.h>
-#include <kdebug.h>
+#include <qstyle.h>
 #include <kprogress.h>
 #include <kstatusbar.h>
 #include <kinputdialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
+#include <kpopupmenu.h>
 
 //////////////////////////////////////////////////////////////////////////
 //  The following is KrDetailedView's settings in KConfig:
@@ -79,12 +82,16 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #define COLUMN(X)	static_cast<KrDetailedViewProperties*>(_properties)->column[ KrDetailedViewProperties::X ]
 #define PROPS	static_cast<KrDetailedViewProperties*>(_properties)	
 
+#define COLUMN_POPUP_IDS    91
+
 QString KrDetailedView::ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
 
 KrDetailedView::KrDetailedView( QWidget *parent, ListPanel *panel, bool &left, KConfig *cfg, const char *name ) :
       KListView( parent, name ), KrView( cfg ), _focused( false ), _currDragItem( 0L ),
-_nameInKConfig( QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right" ) ) ), _left( left ) {
+      _nameInKConfig( QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right" ) ) ), _left( left ),
+      currentlyRenamedItem( 0 )    {
 	initProperties(); // don't forget this!
+        lastSwushPosition = 0;
 
    if ( ColumnName[ 0 ].isEmpty() ) {
       ColumnName[ 0 ] = i18n( "Name" );
@@ -118,6 +125,7 @@ _nameInKConfig( QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right"
       connect( this, SIGNAL( mouseButtonClicked ( int, QListViewItem *, const QPoint &, int ) ),
                this, SLOT( slotMouseClicked ( int, QListViewItem *, const QPoint &, int ) ) );
       connect( &KrColorCache::getColorCache(), SIGNAL( colorsRefreshed() ), this, SLOT( refreshColors() ) );
+		connect( header(), SIGNAL(clicked(int)), this, SLOT(sortOrderChanged(int )));
    }
 
    setWidget( this );
@@ -175,8 +183,8 @@ _nameInKConfig( QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right"
    setAcceptDrops( true );
    setDragEnabled( true );
    setTooltipColumn( COLUMN(Name) );
-   //setDropVisualizer(false);
-   //setDropHighlighter(false);
+   setDropVisualizer(false);
+   setDropHighlighter(true);
    setSelectionModeExt( KListView::FileManager );
    setAllColumnsShowFocus( true );
    setShowSortIndicator( true );
@@ -187,6 +195,9 @@ _nameInKConfig( QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right"
    //-->  setRenameable( column( Name ), true );
    //-------------------------------------------------------------------------------
 
+   header()->installEventFilter( this );
+   renameLineEdit()->installEventFilter( this );
+   
    // allow in-place renaming
    connect( renameLineEdit(), SIGNAL( done( QListViewItem *, int ) ),
             this, SLOT( inplaceRenameFinished( QListViewItem*, int ) ) );
@@ -238,7 +249,7 @@ void KrDetailedView::newColumn( KrDetailedViewProperties::ColumnType type ) {
 int KrDetailedView::column( KrDetailedViewProperties::ColumnType type ) {
 	return PROPS->column[type];
 }
-
+ 
 void KrDetailedView::addItem( vfile *vf ) {
    QString size = KRpermHandler::parseSize( vf->vfile_getSize() );
    QString name = vf->vfile_getName();
@@ -248,7 +259,7 @@ void KrDetailedView::addItem( vfile *vf ) {
             case KrViewProperties::All :
                break;
             case KrViewProperties::Custom :
-            if ( !QDir::match( _properties->filterMask, name ) ) return ;
+            if ( !_properties->filterMask.match( vf ) ) return ;
             break;
             case KrViewProperties::Dirs:
             if ( !vf->vfile_isDir() ) return ;
@@ -266,11 +277,9 @@ void KrDetailedView::addItem( vfile *vf ) {
    dict.insert( vf->vfile_getName(), item );
    if ( isDir )
       ++_numDirs;
-   else _countSize += dynamic_cast<KrViewItem*>( item ) ->size();
+   else _countSize += static_cast<KrViewItem*>( item ) ->size();
    ++_count;
    
-   //kdWarning() << "===> " << nameToMakeCurrent() << endl;
-   
    if (item->name() == nameToMakeCurrent() )
       setCurrentItem(item->name()); // dictionary based - quick
 
@@ -281,7 +290,7 @@ void KrDetailedView::addItem( vfile *vf ) {
 void KrDetailedView::delItem( const QString &name ) {
 	 KrDetailedViewItem * it = dict[ name ];
    if ( !it ) {
-      kdWarning() << "got signal deletedVfile(" << name << ") but can't find KrViewItem" << endl;
+      krOut << "got signal deletedVfile(" << name << ") but can't find KrViewItem" << endl;
 		return;
 	} 
 	if (it->isDir()) {
@@ -300,11 +309,10 @@ void KrDetailedView::updateItem( vfile *vf ) {
    // it's properties first and repair it later
    KrDetailedViewItem * it = dict[ vf->vfile_getName() ];
    if ( !it ) {
-      kdWarning() << "got signal updatedVfile(" << vf->vfile_getName() << ") but can't find KrViewItem" << endl;
+      krOut << "got signal updatedVfile(" << vf->vfile_getName() << ") but can't find KrViewItem" << endl;
    } else {
 		bool selected = it->isSelected();
       bool current = ( getCurrentKrViewItem() == it );
-//    kdWarning() << "updated" << endl;
       delItem( vf->vfile_getName() );
       addItem( vf );
       // restore settings
@@ -323,7 +331,7 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
 
    // add the up-dir arrow if needed
    if ( addUpDir ) {
-      KListViewItem * item = new KrDetailedViewItem( this, ( QListViewItem* ) 0L, ( vfile* ) 0L );
+      new KrDetailedViewItem( this, ( QListViewItem* ) 0L, ( vfile* ) 0L );
    }
 
    // add a progress bar to the totals statusbar
@@ -345,7 +353,7 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
                case KrViewProperties::All :
                break;
                case KrViewProperties::Custom :
-               if ( !QDir::match( _properties->filterMask, name ) )
+               if ( !_properties->filterMask.match( vf ) )
                   continue;
                break;
                case KrViewProperties::Dirs:
@@ -362,17 +370,16 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
          }
       }
 
-      item = new KrDetailedViewItem( this, item, vf );
-      dict.insert( vf->vfile_getName(), dynamic_cast<KrDetailedViewItem*>(item) );
+      KrDetailedViewItem *dvitem = new KrDetailedViewItem( this, item, vf );
+      dict.insert( vf->vfile_getName(), dvitem );
       if ( isDir )
          ++_numDirs;
       else
-         _countSize += dynamic_cast<KrViewItem*>( item ) ->size();
+         _countSize += dvitem->size();
       ++_count;
       // if the item should be current - make it so
-      if ( ( dynamic_cast<KrViewItem*>( item ) ) ->
-            name() == nameToMakeCurrent() )
-         currentItem = item;
+      if ( dvitem->name() == nameToMakeCurrent() )
+         currentItem = static_cast<QListViewItem*>(dvitem);
 
       cnt++;
       //    if (cnt % 300 == 0) {
@@ -410,7 +417,7 @@ void KrDetailedView::setCurrentItem( const QString& name ) {
       KListView::setCurrentItem( it );
 #if 0
    for ( QListViewItem * it = firstChild(); it != 0; it = it->itemBelow() )
-      if ( dynamic_cast<KrViewItem*>( it ) ->
+      if ( static_cast<KrViewItem*>( it ) ->
             name() == name ) {
          KListView::setCurrentItem( it );
          break;
@@ -433,8 +440,11 @@ void KrDetailedView::setSortMode( KrViewProperties::SortSpec mode ) {
    if ( mode & KrViewProperties::Name )
       cl = COLUMN( Name );
    else
+	if ( mode & KrViewProperties::Ext )
+      cl = COLUMN( Extention );
+	else
       if ( mode & KrViewProperties::Size )
-         cl = COLUMN( Extention );
+         cl = COLUMN( Size );
       else
          if ( mode & KrViewProperties::Type )
             cl = COLUMN( Mime );
@@ -515,7 +525,7 @@ void KrDetailedView::prepareForPassive() {
 }
 
 void KrDetailedView::slotItemDescription( QListViewItem * item ) {
-   KrViewItem * it = dynamic_cast<KrViewItem*>( item );
+   KrViewItem * it = static_cast<KrDetailedViewItem*>( item );
    if ( !it )
       return ;
    QString desc = it->description();
@@ -544,7 +554,7 @@ void KrDetailedView::slotCurrentChanged( QListViewItem * item ) {
    CANCEL_TWO_CLICK_RENAME;
    if ( !item )
       return ;
-   _nameToMakeCurrent = dynamic_cast<KrViewItem*>( item ) ->name();
+   _nameToMakeCurrent = static_cast<KrDetailedViewItem*>( item ) ->name();
 }
 
 void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
@@ -553,13 +563,19 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
    QListViewItem *newCurrent = itemAt( contentsToViewport( e->pos() ) );
    if (e->button() == RightButton)
    {
-     if (KrSelectionMode::getSelectionHandler()->rightButtonSelects())
+	if (KrSelectionMode::getSelectionHandler()->rightButtonSelects() || 
+		(((e->state() & ShiftButton) || (e->state() & ControlButton))) && KrSelectionMode::getSelectionHandler()->shiftCtrlRightButtonSelects())
      {
        if (KrSelectionMode::getSelectionHandler()->rightButtonPreservesSelection() && !(e->state() & ShiftButton)
           && !(e->state() & ControlButton) && !(e->state() & AltButton))
        {
          if (newCurrent)
          {
+           if (KrSelectionMode::getSelectionHandler()->showContextMenu() >= 0)
+           {
+             swushSelects = !newCurrent->isSelected();
+             lastSwushPosition = newCurrent;
+           }
            newCurrent->setSelected(!newCurrent->isSelected());
            newCurrent->repaint();
 			  selectionChanged = true;
@@ -578,7 +594,10 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
    }
    if (e->button() == LeftButton)
    {
-     if (KrSelectionMode::getSelectionHandler()->leftButtonSelects())
+     dragStartPos = e->pos();
+	  if (KrSelectionMode::getSelectionHandler()->leftButtonSelects() || 
+	  		(((e->state() & ShiftButton) || (e->state() & ControlButton))) &&
+			KrSelectionMode::getSelectionHandler()->shiftCtrlLeftButtonSelects())
      {
        if (KrSelectionMode::getSelectionHandler()->leftButtonPreservesSelection() && !(e->state() & ShiftButton)
           && !(e->state() & ControlButton) && !(e->state() & AltButton))
@@ -655,7 +674,10 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
 	
    //   QListViewItem * i = itemAt( contentsToViewport( e->pos() ) );
    if (callDefaultHandler)
+   {
+     dragStartPos = QPoint( -1, -1 );
      KListView::contentsMousePressEvent( e );
+   }
    //   if (i != 0) // comment in, if click sould NOT select
    //     setSelected(i, FALSE);
    if (newCurrent) QListView::setCurrentItem(newCurrent);
@@ -681,7 +703,48 @@ void KrDetailedView::contentsMouseReleaseEvent( QMouseEvent * e ) {
 void KrDetailedView::contentsMouseMoveEvent ( QMouseEvent * e ) {
    if ( ( singleClicked || renameTimer.isActive() ) && itemAt( contentsToViewport( e->pos() ) ) != clickedItem )
       CANCEL_TWO_CLICK_RENAME;
-   KListView::contentsMouseMoveEvent( e );
+   if ( dragStartPos != QPoint( -1, -1 ) &&
+        e->state() & LeftButton && ( dragStartPos - e->pos() ).manhattanLength() > QApplication::startDragDistance() )
+      startDrag();
+   if (KrSelectionMode::getSelectionHandler()->rightButtonPreservesSelection() 
+      && KrSelectionMode::getSelectionHandler()->rightButtonSelects() 
+      && KrSelectionMode::getSelectionHandler()->showContextMenu() >= 0 && e->state() == Qt::RightButton)
+      {
+         QListViewItem *newItem = itemAt( contentsToViewport( e->pos() ) );
+         e->accept();
+         if (newItem != lastSwushPosition && newItem)
+         {
+           // is the new item above or below the previous one?
+           QListViewItem * above = newItem;
+           QListViewItem * below = newItem;
+           for (;(above || below) && above != lastSwushPosition && below != lastSwushPosition;)
+           {
+             if (above)
+               above = above->itemAbove();
+             if (below)
+               below = below->itemBelow();
+           }
+           if (above == lastSwushPosition)
+           {
+             for (; above != newItem; above = above->itemBelow())
+               above->setSelected(swushSelects);
+             newItem->setSelected(swushSelects);
+             lastSwushPosition = newItem;
+             updateView();
+           }
+           else if (below == lastSwushPosition)
+           {
+             for (; below != newItem; below = below->itemAbove())
+               below->setSelected(swushSelects);
+             newItem->setSelected(swushSelects);
+             lastSwushPosition = newItem;
+             updateView();
+           }
+           contextMenuTimer.stop();
+         }
+      }
+      else
+         KListView::contentsMouseMoveEvent( e );
 }
 
 void KrDetailedView::contentsWheelEvent( QWheelEvent * e ) {
@@ -695,7 +758,7 @@ void KrDetailedView::handleContextMenu( QListViewItem * it, const QPoint & pos,
       emit needFocus();
    if ( !it )
       return ;
-   if ( dynamic_cast<KrViewItem*>( it ) ->
+   if ( static_cast<KrDetailedViewItem*>( it ) ->
          name() == ".." )
       return ;
    int i = KrSelectionMode::getSelectionHandler()->showContextMenu();
@@ -708,6 +771,8 @@ void KrDetailedView::handleContextMenu( QListViewItem * it, const QPoint & pos,
 
 void KrDetailedView::showContextMenu()
 {
+	if (lastSwushPosition)
+		lastSwushPosition->setSelected(true);
    emit contextMenu( contextMenuPoint );
 }
 
@@ -725,16 +790,27 @@ void KrDetailedView::startDrag() {
 }
 
 KrViewItem *KrDetailedView::getKrViewItemAt( const QPoint & vp ) {
-   return dynamic_cast<KrViewItem*>( KListView::itemAt( vp ) );
+   return static_cast<KrDetailedViewItem*>( KListView::itemAt( vp ) );
 }
 
 bool KrDetailedView::acceptDrag( QDropEvent* ) const {
    return true;
 }
 
+QRect KrDetailedView::drawItemHighlighter(QPainter *painter, QListViewItem *item)
+{
+  QRect r;
+  if( _currDragItem && item ) {
+    r = itemRect(item);
+
+    if (painter)
+       style().drawPrimitive(QStyle::PE_FocusRect, painter, r, colorGroup(),
+                             QStyle::Style_FocusAtBorder, colorGroup().highlight());
+  }
+  return r;
+}
+
 void KrDetailedView::contentsDropEvent( QDropEvent * e ) {
-   /*  if (_currDragItem)
-       dynamic_cast<KListViewItem*>(_currDragItem)->setPixmap(column(Name), FL_LOADICON("folder"));*/
    e->setPoint( contentsToViewport( e->pos() ) );
    emit gotDrop( e );
    e->ignore();
@@ -742,28 +818,10 @@ void KrDetailedView::contentsDropEvent( QDropEvent * e ) {
 }
 
 void KrDetailedView::contentsDragMoveEvent( QDragMoveEvent * e ) {
-   /*  KrViewItem *i=getKrViewItemAt(contentsToViewport(e->pos()));
-     // reset the last used icon
-     if (_currDragItem != i && _currDragItem)
-       dynamic_cast<KListViewItem*>(_currDragItem)->setPixmap(column(Name), FL_LOADICON("folder"));
-     if (!i) {
-       e->acceptAction();
-       _currDragItem = 0L;
-       KListView::contentsDragMoveEvent(e);
-       return;
-     }
-     // otherwise, check if we're dragging on a directory
-     if (i->name()=="..") {
-       _currDragItem = 0L;
-       e->acceptAction();
-       KListView::contentsDragMoveEvent(e);
-       return;
-     }
-     if (i->isDir()) {
-       dynamic_cast<KListViewItem*>(i)->setPixmap(column(Name),FL_LOADICON("folder_open"));
-       _currDragItem = i;
-       KListView::contentsDragMoveEvent(e);
-     }*/
+   _currDragItem = getKrViewItemAt(contentsToViewport(e->pos()));
+   if( _currDragItem && !_currDragItem->isDir() )
+     _currDragItem = 0;
+   
    KListView::contentsDragMoveEvent( e );
 }
 
@@ -913,7 +971,8 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
          break;
 #endif*/
          case Key_Delete :                   // kill file
-         SLOTS->deleteFiles();
+         SLOTS->deleteFiles(e->state() == ShiftButton);
+				
          return ;
          case Key_Insert : {
             if (KrSelectionMode::getSelectionHandler()->insertMovesDown())
@@ -923,7 +982,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
             return ; 
          }
          case Key_Space : {
-            KrDetailedViewItem * viewItem = dynamic_cast<KrDetailedViewItem *> ( getCurrentKrViewItem() );
+            KrDetailedViewItem * viewItem = static_cast<KrDetailedViewItem *> ( getCurrentKrViewItem() );
             if ( !viewItem || viewItem->name() == ".." ) { // wrong type, just mark(unmark it)
                if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
                   KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Insert, 0, 0 ) );
@@ -1011,9 +1070,10 @@ void KrDetailedView::rename( QListViewItem * item, int c ) {
    // do we have an EXT column? if so, handle differently:
    // copy the contents of the EXT column over to the name
    if ( COLUMN( Extention ) != -1 ) {
-      item->setText( COLUMN( Name ), dynamic_cast<KrViewItem*>( item ) ->name() );
+      item->setText( COLUMN( Name ), static_cast<KrDetailedViewItem*>( item ) ->name() );
       item->setText( COLUMN( Extention ), QString::null );
       repaintItem( item );
+      currentlyRenamedItem = item;
    }
 
    renameLineEdit()->setBackgroundMode(Qt::FixedColor);
@@ -1027,7 +1087,7 @@ void KrDetailedView::renameCurrentItem() {
    int c;
    QString newName, fileName;
 
-   KrViewItem *it = getCurrentKrViewItem();
+   KrDetailedViewItem *it = static_cast<KrDetailedViewItem*>(getCurrentKrViewItem());
    if ( it )
       fileName = it->name();
    else
@@ -1044,7 +1104,7 @@ void KrDetailedView::renameCurrentItem() {
       c = -1; // failsafe
 
    if ( c >= 0 ) {
-      rename( dynamic_cast<QListViewItem*>( it ), c );
+      rename( static_cast<QListViewItem*>( it ), c );
       // signal will be emited when renaming is done, and finalization
       // will occur in inplaceRenameFinished()
    } else { // do this in case inplace renaming is disabled
@@ -1061,19 +1121,23 @@ void KrDetailedView::renameCurrentItem() {
 
 void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
    if ( !it ) { // major failure - call developers
-      kdWarning() << "Major failure at inplaceRenameFinished(): item is null" << endl;
+      krOut << "Major failure at inplaceRenameFinished(): item is null" << endl;
       return;
    }
+   
+   if( COLUMN( Extention ) != -1 && !currentlyRenamedItem )
+     return; /* does the event filter restored the original state? */
+   
    // check if the item was indeed renamed
    bool restoreView = false;
-   if ( it->text( COLUMN( Name ) ) != dynamic_cast<KrDetailedViewItem*>( it ) ->name() ) { // was renamed
-      emit renameItem( dynamic_cast<KrDetailedViewItem*>( it ) ->name(), it->text( COLUMN( Name ) ) );
+   if ( it->text( COLUMN( Name ) ) != static_cast<KrDetailedViewItem*>( it ) ->name() ) { // was renamed
+      emit renameItem( static_cast<KrDetailedViewItem*>( it ) ->name(), it->text( COLUMN( Name ) ) );
    } else restoreView = true;
 
    if ( COLUMN( Extention ) != -1 && restoreView ) { // nothing happened, restore the view (if needed)
       int i;
-      QString ext, name = dynamic_cast<KrDetailedViewItem*>( it ) ->name();
-      if ( !dynamic_cast<KrDetailedViewItem*>( it ) ->isDir() )
+      QString ext, name = static_cast<KrDetailedViewItem*>( it ) ->name();
+      if ( !static_cast<KrDetailedViewItem*>( it ) ->isDir() )
          if ( ( i = name.findRev( '.' ) ) > 0 ) {
             ext = name.mid( i + 1 );
             name = name.mid( 0, i );
@@ -1083,6 +1147,8 @@ void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
       repaintItem( it );
    }
    setFocus();
+   
+   currentlyRenamedItem = 0;
 }
 
 void KrDetailedView::quickSearch( const QString & str, int direction ) {
@@ -1110,11 +1176,13 @@ void KrDetailedView::quickSearch( const QString & str, int direction ) {
 }
 
 void KrDetailedView::stopQuickSearch( QKeyEvent * e ) {
-   ACTIVE_PANEL->quickSearch->hide();
-   ACTIVE_PANEL->quickSearch->clear();
-   krDirUp->setEnabled( true );
-   if ( e )
-      keyPressEvent( e );
+   if( ACTIVE_PANEL && ACTIVE_PANEL->quickSearch ) {
+     ACTIVE_PANEL->quickSearch->hide();
+     ACTIVE_PANEL->quickSearch->clear();
+     krDirUp->setEnabled( true );
+     if ( e )
+        keyPressEvent( e );
+   }
 }
 
 //void KrDetailedView::focusOutEvent( QFocusEvent * e )
@@ -1125,7 +1193,8 @@ void KrDetailedView::stopQuickSearch( QKeyEvent * e ) {
 //}
 
 void KrDetailedView::setNameToMakeCurrent( QListViewItem * it ) {
-   KrView::setNameToMakeCurrent( dynamic_cast<KrViewItem*>( it ) ->name() );
+	if (!it) return;
+   KrView::setNameToMakeCurrent( static_cast<KrDetailedViewItem*>( it ) ->name() );
 }
 
 void KrDetailedView::slotMouseClicked( int button, QListViewItem * item, const QPoint&, int ) {
@@ -1138,7 +1207,7 @@ void KrDetailedView::refreshColors() {
       // KDE deafult is not choosen: set the background color (as this paints the empty areas) and the alternate color
       bool isActive = hasFocus();
       if ( MAIN_VIEW && ACTIVE_PANEL && ACTIVE_PANEL->view )
-         isActive = ( dynamic_cast<KrView *>( this ) == ACTIVE_PANEL->view );
+         isActive = ( static_cast<KrView *>( this ) == ACTIVE_PANEL->view );
       QColor color = KrColorCache::getColorCache().getBackgroundColor( isActive );
       setPaletteBackgroundColor( color );
       color = KrColorCache::getColorCache().getAlternateBackgroundColor( isActive );
@@ -1166,9 +1235,38 @@ bool KrDetailedView::event( QEvent *e ) {
    return KListView::event( e );
 }
 
+bool KrDetailedView::eventFilter( QObject * watched, QEvent * e )
+{
+  if( watched == renameLineEdit() )
+  {
+    if( currentlyRenamedItem && e->type() == QEvent::Hide )
+    {
+      /* checking if the currentlyRenamedItem pointer is valid (vfs_refresh can delete this item) */
+      for( QListViewItem *it = firstChild(); it; it = it->nextSibling() )
+        if( it == currentlyRenamedItem )
+        {
+          if ( it->text( COLUMN( Name ) ) == dynamic_cast<KrDetailedViewItem*>( it ) ->name()  && COLUMN( Extention ) != -1 ) 
+            inplaceRenameFinished( it, COLUMN( Name ) );
+          break;
+        }
+    }
+    return FALSE;
+  }
+  else if( watched == header() )
+  {
+    if( e->type() == QEvent::MouseButtonPress && ((QMouseEvent *)e )->button() == Qt::RightButton )
+    {
+      selectColumns();
+      return TRUE;
+    }
+    return FALSE;
+  }
+  return KListView::eventFilter( watched, e );
+}
+
 void KrDetailedView::makeItemVisible( const KrViewItem *item ) {
 	qApp->processEvents();
-	ensureItemVisible( dynamic_cast<const QListViewItem*>( item ) ); 
+	ensureItemVisible( static_cast<const KrDetailedViewItem*>( item ) ); 
 }
 
 void KrDetailedView::initProperties() {
@@ -1183,6 +1281,99 @@ void KrDetailedView::initProperties() {
 				 KrViewProperties::IgnoreCase );
 	PROPS->humanReadableSize = krConfig->readBoolEntry("Human Readable Size", _HumanReadableSize);
 	}
+	PROPS->localeAwareCompareIsCaseSensitive = QString( "a" ).localeAwareCompare( "B" ) > 0; // see KDE bug #40131
 }
 
+void KrDetailedView::selectColumns()
+{
+  KPopupMenu popup( this );
+  popup.insertTitle( i18n("Columns"));
+  
+  bool refresh = false;
+  
+  bool hasExtention = COLUMN( Extention ) != -1;
+  bool hasMime      = COLUMN( Mime ) != -1;
+  bool hasSize      = COLUMN( Size ) != -1;
+  bool hasDate      = COLUMN( DateTime ) != -1;
+  bool hasPerms     = COLUMN( Permissions ) != -1;
+  bool hasKrPerms   = COLUMN( KrPermissions ) != -1;
+  bool hasOwner     = COLUMN( Owner ) != -1;
+  bool hasGroup     = COLUMN( Group ) != -1;
+  
+  popup.insertItem( i18n( "Ext" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::Extention );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::Extention, hasExtention );
+
+  popup.insertItem( i18n( "Type" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::Mime );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::Mime, hasMime );
+
+  popup.insertItem( i18n( "Size" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::Size );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::Size, hasSize );
+
+  popup.insertItem( i18n( "Modified" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::DateTime );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::DateTime, hasDate );
+
+  popup.insertItem( i18n( "Perms" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::Permissions );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::Permissions, hasPerms );
+
+  popup.insertItem( i18n( "rwx" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::KrPermissions );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::KrPermissions, hasKrPerms );      
+
+  popup.insertItem( i18n( "Owner" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::Owner );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::Owner, hasOwner );      
+
+  popup.insertItem( i18n( "Group" ), COLUMN_POPUP_IDS + KrDetailedViewProperties::Group );
+  popup.setItemChecked( COLUMN_POPUP_IDS + KrDetailedViewProperties::Group, hasGroup );        
+  
+  int result=popup.exec(QCursor::pos());
+
+  krConfig->setGroup( "Look&Feel" );
+  
+  switch( result - COLUMN_POPUP_IDS )
+  {
+  case KrDetailedViewProperties::Extention:
+    krConfig->writeEntry( "Ext Column", !hasExtention );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::Mime:
+    krConfig->writeEntry( "Mime Column", !hasMime );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::Size:
+    krConfig->writeEntry( "Size Column", !hasSize );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::DateTime:
+    krConfig->writeEntry( "DateTime Column", !hasDate );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::Permissions:
+    krConfig->writeEntry( "Perm Column", !hasPerms );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::KrPermissions:
+    krConfig->writeEntry( "KrPerm Column", !hasKrPerms );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::Owner:
+    krConfig->writeEntry( "Owner Column", !hasOwner );
+    refresh = true;
+    break;
+  case KrDetailedViewProperties::Group:
+    krConfig->writeEntry( "Group Column", !hasGroup );
+    refresh = true;
+    break;
+  }
+  
+  if( refresh )
+  {
+    QTimer::singleShot( 0, MAIN_VIEW->leftMng, SLOT( slotRecreatePanels() ) );
+    QTimer::singleShot( 0, MAIN_VIEW->rightMng, SLOT( slotRecreatePanels() ) );
+  }
+}
+
+void KrDetailedView::sortOrderChanged(int) {
+	ensureItemVisible(currentItem());
+}
+
+
 #include "krdetailedview.moc"
