@@ -98,7 +98,8 @@ void KrView::getSelectedItems( QStringList *names ) {
       if ( it->isSelected() && ( it->name() != ".." ) ) names->append( it->name() );
 
    // if all else fails, take the current item
-   if ( names->empty() && ( getCurrentItem() != ".." ) ) names->append( getCurrentItem() );
+	QString item = getCurrentItem();
+   if ( names->empty() && item!=QString::null && item!=".." ) names->append( item );
 }
 
 void KrView::getSelectedKrViewItems( KrViewItemList *items ) {
@@ -106,7 +107,8 @@ void KrView::getSelectedKrViewItems( KrViewItemList *items ) {
       if ( it->isSelected() && ( it->name() != ".." ) ) items->append( it );
 
    // if all else fails, take the current item
-   if ( items->empty() && ( getCurrentItem() != ".." ) ) items->append( getCurrentKrViewItem() );
+	QString item = getCurrentItem();
+   if ( items->empty() && item!=QString::null && item!=".." ) items->append( getCurrentKrViewItem() );
 }
 
 QString KrView::statistics() {
@@ -127,7 +129,7 @@ QString KrView::statistics() {
    return tmp;
 }
 
-void KrView::changeSelection( const QString& filter, bool select, bool includeDirs ) {
+void KrView::changeSelection( const KRQuery& filter, bool select, bool includeDirs ) {
    KConfigGroupSaver grpSvr( _config, "Look&Feel" );
    bool markDirs = _config->readBoolEntry( "Mark Dirs", _MarkDirs ) || includeDirs;
 
@@ -135,7 +137,11 @@ void KrView::changeSelection( const QString& filter, bool select, bool includeDi
    for ( KrViewItem * it = getFirst(); it != 0; it = getNext( it ) ) {
       if ( it->name() == ".." ) continue;
       if ( it->isDir() && !markDirs ) continue;
-      if ( QDir::match( filter, it->name() ) ) {
+      
+      vfile * file = it->getVfile();
+      if( file == 0 ) continue;
+      
+      if( filter.match( file ) ) {
          // we're increasing/decreasing the number of selected files
          if ( select ) {
             if ( !it->isSelected() ) {
