@@ -69,6 +69,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 // Krusader includes
 #include "../krusader.h"
 #include "../krslots.h"
+#include "panelfunc.h"
 #include "../kicons.h"
 #include "../VFS/krpermhandler.h"
 #include "listpanel.h"
@@ -76,7 +77,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../panelmanager.h"
 #include "../defaults.h"
 #include "../resources.h"
-#include "panelfunc.h"
 #include "../MountMan/kmountman.h"
 #include "../Dialogs/krdialogs.h"
 #include "../BookMan/krbookmarkbutton.h"
@@ -91,6 +91,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../krservices.h"
 #include "panelpopup.h" 
 #include "../UserAction/useractionpopupmenu.h"
+#include "../Dialogs/popularurls.h"
 
 #ifdef __LIBKONQ__
 #include <konq_popupmenu.h>
@@ -99,12 +100,14 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 
 typedef QValueList<KServiceOffer> OfferList;
 
+#define URL(X) KURL::fromPathOrURL(X)
+
 /////////////////////////////////////////////////////
 // 					The list panel constructor             //
 /////////////////////////////////////////////////////
 ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
       QWidget( parent, name ), colorMask( 255 ), compareMode( false ), currDragItem( 0 ), statsAgent( 0 ), 
-		quickSearch( 0 ), cdRootButton( 0 ), cdUpButton( 0 ), popupBtn(0), popup(0), _left( left ) {
+		quickSearch( 0 ), cdRootButton( 0 ), cdUpButton( 0 ), popupBtn(0), popup(0), _left( left ), inlineRefreshJob(0) {
 
    func = new ListPanelFunc( this );
    setAcceptDrops( true );
@@ -121,7 +124,7 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
    int sheight = QFontMetrics( status->font() ).height() + 4;
    status->setMaximumHeight( sheight );
    QWhatsThis::add
-      ( status, i18n( "The status bar displays information about the FILESYSTEM "
+      ( status, i18n( "The statusbar displays information about the FILESYSTEM "
                       "which holds your current directory: Total size, free space, "
                       "type of filesystem, etc." ) );
    connect( status, SIGNAL( clicked() ), this, SLOT( slotFocusOnMe() ) );
@@ -131,11 +134,11 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
    dirHistoryQueue = new DirHistoryQueue( this );
    historyButton = new DirHistoryButton( dirHistoryQueue, this, "historyButton" );
    connect( historyButton, SIGNAL( pressed() ), this, SLOT( slotFocusOnMe() ) );
-   connect( historyButton, SIGNAL( openUrl( const KURL& ) ), func, SLOT( delayedOpenUrl( const KURL& ) ) );
+   connect( historyButton, SIGNAL( openUrl( const KURL& ) ), func, SLOT( openUrl( const KURL& ) ) );
 
 	bookmarksButton = new KrBookmarkButton(this);
 	connect( bookmarksButton, SIGNAL( pressed() ), this, SLOT( slotFocusOnMe() ) );
-   connect( bookmarksButton, SIGNAL( openUrl( const KURL& ) ), func, SLOT( delayedOpenUrl( const KURL& ) ) );
+   connect( bookmarksButton, SIGNAL( openUrl( const KURL& ) ), func, SLOT( openUrl( const KURL& ) ) );
 	QWhatsThis::add
       ( bookmarksButton, i18n( "Open menu with bookmarks. You can also add "
                                "current location to the list, edit bookmarks "
@@ -156,13 +159,20 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
    connect( totals, SIGNAL( clicked() ), this, SLOT( slotFocusOnMe() ) );
    connect( totals, SIGNAL( dropped( QDropEvent *) ), this, SLOT( handleDropOnTotals(QDropEvent *) ) );  
    
+	// a cancel button for the inplace refresh mechanism
+	inlineRefreshCancelButton = new KPushButton(this);
+	inlineRefreshCancelButton->setFixedSize( 22, 20 );
+	inlineRefreshCancelButton->setPixmap(krLoader->loadIcon("cancel", KIcon::Toolbar, 16));
+	connect(inlineRefreshCancelButton, SIGNAL(clicked()), this, SLOT(inlineRefreshCancel()));
+	
 	// a quick button to open the popup panel
 	popupBtn = new QToolButton( this, "popupbtn" );
-   popupBtn->setFixedSize( 20, 20 );
-	popupBtn->setPixmap(krLoader->loadIcon("up", KIcon::Toolbar, 16));
+	popupBtn->setFixedSize( 22, 20 );
+	popupBtn->setPixmap(krLoader->loadIcon("1uparrow", KIcon::Toolbar, 16));
 	connect(popupBtn, SIGNAL(clicked()), this, SLOT(togglePanelPopup()));
 	QToolTip::add(  popupBtn, i18n( "Open the popup panel" ) );
 	totalsLayout->addWidget(totals);
+	totalsLayout->addWidget(inlineRefreshCancelButton); inlineRefreshCancelButton->hide();
 	totalsLayout->addWidget(popupBtn);
    
    quickSearch = new KrQuickSearch( this );
@@ -274,8 +284,6 @@ ListPanel::~ListPanel() {
 
 void ListPanel::togglePanelPopup() {
 	if (popup->isHidden()) {
-		popup->show();
-		
 		if (popupSizes.count() > 0) {
 			dynamic_cast<QSplitter*>(popup->parent())->setSizes(popupSizes);
 		} else { // on the first time, resize to 50%
@@ -283,13 +291,15 @@ void ListPanel::togglePanelPopup() {
 			lst << height()/2 << height()/2;
 			dynamic_cast<QSplitter*>(popup->parent())->setSizes(lst);
 		}
-		popupBtn->setPixmap(krLoader->loadIcon("down", KIcon::Toolbar, 16));
+		
+		popup->show();
+		popupBtn->setPixmap(krLoader->loadIcon("1downarrow", KIcon::Toolbar, 16));
 		QToolTip::add(  popupBtn, i18n( "Close the popup panel" ) );
 	} else {
 		popupSizes.clear();
 		popupSizes = dynamic_cast<QSplitter*>(popup->parent())->sizes();
 		popup->hide();
-		popupBtn->setPixmap(krLoader->loadIcon("up", KIcon::Toolbar, 16));
+		popupBtn->setPixmap(krLoader->loadIcon("1uparrow", KIcon::Toolbar, 16));
 		QToolTip::add(  popupBtn, i18n( "Open the popup panel" ) );
 		
 		QValueList<int> lst;
@@ -298,6 +308,15 @@ void ListPanel::togglePanelPopup() {
 	}
 }
 
+KURL ListPanel::virtualPath() const {
+	return func->files()->vfs_getOrigin(); 
+}
+
+QString ListPanel::realPath() const { 
+	return _realPath.path(); 
+}
+
+
 void ListPanel::setPanelToolbar() {
    krConfig->setGroup( "Look&Feel" );
 
@@ -359,30 +378,32 @@ void ListPanel::slotFocusAndCDRoot() {
    func->openUrl( QString( "/" ), QString::null );
 }
 
-void ListPanel::select(QString mask, bool select) {
-	if (mask != QString::null) {
-		if ( select )
-         view->select( mask );
+void ListPanel::select( KRQuery query, bool select) {
+   if ( !query.isNull() ) {
+      if ( select )
+         view->select( query );
       else
-         view->unselect( mask );
-	}
+         view->unselect( query );
+   }
 }
 
 void ListPanel::select( bool select, bool all ) {
    if ( all )
+   {
       if ( select )
-         view->select( QString( "*" ) );
+         view->select( KRQuery( "*" ) );
       else
-         view->unselect( QString( "*" ) );
+         view->unselect( KRQuery( "*" ) );
+   }
    else {
-      QString answer = KRSpWidgets::getMask( ( select ? i18n( " Select Files " ) : i18n( " Unselect Files " ) ) );
+      KRQuery query = KRSpWidgets::getMask( ( select ? i18n( " Select Files " ) : i18n( " Unselect Files " ) ) );
       // if the user canceled - quit
-      if ( answer == QString::null )
+      if ( query.isNull() )
          return ;
       if ( select )
-         view->select( answer );
+         view->select( query );
       else
-         view->unselect( answer );
+         view->unselect( query );
    }
 }
 
@@ -466,7 +487,7 @@ void ListPanel::slotFocusOnMe() {
    totals->setPalette( p );
 
    view->prepareForActive();
-   emit cmdLineUpdate( realPath );
+   emit cmdLineUpdate( realPath() );
    emit activePanelChanged( this );
 
    func->refreshActions();
@@ -480,66 +501,70 @@ void ListPanel::slotFocusOnMe() {
 
 // this is used to start the panel, AFTER setOther() has been used
 //////////////////////////////////////////////////////////////////
-void ListPanel::start( QString path ) {
+void ListPanel::start( KURL url, bool immediate ) {
    bool left = _left;
-   krConfig->setGroup( "Startup" );
+   KURL virt;
+	krConfig->setGroup( "Startup" );
 
    // set the startup path
-   if ( path != QString::null ) {
-      virtualPath = path;
+   if ( !url.isEmpty() ) {
+      virt = url;
    } else
       if ( left ) {
          if ( krConfig->readEntry( "Left Panel Origin", _LeftPanelOrigin ) == i18n( "homepage" ) )
-            virtualPath = krConfig->readEntry( "Left Panel Homepage", _LeftHomepage );
+            virt = URL(krConfig->readEntry( "Left Panel Homepage", _LeftHomepage ));
          else if ( krConfig->readEntry( "Left Panel Origin" ) == i18n( "the last place it was" ) )
             // read the first of the tabbar. lastHomeLeft is obsolete!
-            virtualPath = (krConfig->readPathListEntry( "Left Tab Bar" ))[0];
+            virt = URL((krConfig->readPathListEntry( "Left Tab Bar" ))[0]);
          else
-            virtualPath = getcwd( 0, 0 ); //get_current_dir_name();
+            virt = URL(getcwd( 0, 0 )); //get_current_dir_name();
       } else { // right
          if ( krConfig->readEntry( "Right Panel Origin", _RightPanelOrigin ) == i18n( "homepage" ) )
-            virtualPath = krConfig->readEntry( "Right Panel Homepage", _RightHomepage );
+            virt = URL(krConfig->readEntry( "Right Panel Homepage", _RightHomepage ));
          else if ( krConfig->readEntry( "Right Panel Origin" ) == i18n( "the last place it was" ) )
             // read the first of the tabbar. lastHomeLeft is obsolete!
-            virtualPath = (krConfig->readPathListEntry( "Right Tab Bar" ))[0];
+            virt = URL((krConfig->readPathListEntry( "Right Tab Bar" ))[0]);
          else
-            virtualPath = getcwd( 0, 0 );
+            virt = URL(getcwd( 0, 0 ));
       }
 
-   realPath = virtualPath;
-   KURL url = vfs::fromPathOrURL( virtualPath );
-   if ( !url.isValid() )
-      url = "/";
-   func->openUrl( url );
+   
+   if ( !virt.isValid() )
+      virt = URL("/");
+   if( virt.isLocalFile() ) _realPath = virt;
+   else _realPath = URL("/");
+
+   if( immediate )
+     func->immediateOpenUrl( virt );
+   else
+     func->openUrl( virt );
 }
 
 void ListPanel::slotStartUpdate() {
    while ( func->inRefresh )
       ; // wait until the last refresh finish
    func->inRefresh = true;  // make sure the next refresh wait for this one
-   krApp->setCursor( KCursor::workingCursor() );
+	if (inlineRefreshJob)
+		inlineRefreshListResult(0);
+   setCursor( KCursor::workingCursor() );
    view->clear();
 
-   // set the virtual path
-   virtualPath = func->files() ->vfs_getOrigin().prettyURL();
-   if ( virtualPath.startsWith( "file:" ) )
-      virtualPath = virtualPath.mid( 5 );
-
    if ( func->files() ->vfs_getType() == vfs::NORMAL )
-      realPath = virtualPath;
-   this->origin->setURL( virtualPath );
+      _realPath = virtualPath();
+   this->origin->setURL( virtualPath().prettyURL() );
    emit pathChanged( this );
-   emit cmdLineUpdate( realPath );	// update the command line
+   emit cmdLineUpdate( realPath() );	// update the command line
 
-   slotGetStats( virtualPath );
+   slotGetStats( virtualPath() );
    slotUpdate();
    if ( compareMode ) {
       otherPanel->view->clear();
       ( ( ListPanel* ) otherPanel ) ->slotUpdate();
    }
    // return cursor to normal arrow
-   krApp->setCursor( KCursor::arrowCursor() );
+   setCursor( KCursor::arrowCursor() );
    slotUpdateTotals();
+	krApp->popularUrls->addUrl(virtualPath());
 }
 
 void ListPanel::slotUpdate() {
@@ -547,7 +572,7 @@ void ListPanel::slotUpdate() {
    QString protocol = func->files() ->vfs_getOrigin().protocol();
    bool isFtp = ( protocol == "ftp" || protocol == "smb" || protocol == "sftp" || protocol == "fish" );
 
-   QString origin = func->files() ->vfs_getOrigin().prettyURL( -1 );
+   QString origin = virtualPath().prettyURL(-1);
    if ( origin.right( 1 ) != "/" && !( ( func->files() ->vfs_getType() == vfs::FTP ) && isFtp &&
                                        origin.find( '/', origin.find( ":/" ) + 3 ) == -1 ) ) {
       view->addItems( func->files() );
@@ -558,13 +583,14 @@ void ListPanel::slotUpdate() {
 }
 
 
-void ListPanel::slotGetStats( QString path ) {
-   if ( path.contains( ":/" ) ) {
+void ListPanel::slotGetStats( const KURL& url ) {
+   if ( !url.isLocalFile() ) {
       status->setText( i18n( "No space information on non-local filesystems" ) );
       return ;
    }
 
 	// check for special filesystems;
+	QString path = url.path(); // must be local url
 	if ( path.left(4) == "/dev") {
 		status->setText(i18n( "No space information on [dev]" ));
 		return;
@@ -643,9 +669,6 @@ void ListPanel::handleDropOnView( QDropEvent *e, QWidget *widget ) {
       file = func->files() ->vfs_search( i->name() );
 
       if ( !file ) { // trying to drop on the ".."
-         if ( virtualPath.right( 1 ) == "\\" )        // root of archive..
-            isWritable = false;
-         else
             copyToDirInPanel = true;
       } else {
          if ( file->vfile_isDir() ) {
@@ -733,34 +756,34 @@ void ListPanel::startDragging( QStringList names, QPixmap px ) {
 // pops a right-click menu for items
 void ListPanel::popRightClickMenu( const QPoint &loc ) {
    // these are the values that will always exist in the menu
-#define OPEN_TAB_ID   89
-#define OPEN_ID       90
-#define OPEN_WITH_ID  91
-#define OPEN_KONQ_ID  92
-#define OPEN_TERM_ID  93
-#define KONQ_MENU_ID  94
-#define CHOOSE_ID     95
-#define DELETE_ID     96
-#define COPY_ID       97
-#define MOVE_ID       98
-#define RENAME_ID     99
-#define PROPERTIES_ID 100
-#define MOUNT_ID      101
-#define UNMOUNT_ID    102
-#define SHRED_ID      103
-#define NEW_LINK      104
-#define NEW_SYMLINK   105
-#define REDIRECT_LINK 106
-#define SEND_BY_EMAIL 107
-#define LINK_HANDLING 108
-#define EJECT_ID      109
-#define PREVIEW_ID    110
-#define COPY_CLIP_ID  111
-#define MOVE_CLIP_ID  112
-#define PASTE_CLIP_ID 113
+#define OPEN_TAB_ID   150089
+#define OPEN_ID       150090
+#define OPEN_WITH_ID  150091
+#define OPEN_KONQ_ID  150092
+#define OPEN_TERM_ID  150093
+#define KONQ_MENU_ID  150094
+#define CHOOSE_ID     150095
+#define DELETE_ID     150096
+#define COPY_ID       150097
+#define MOVE_ID       150098
+#define RENAME_ID     150099
+#define PROPERTIES_ID 150100
+#define MOUNT_ID      150101
+#define UNMOUNT_ID    150102
+#define SHRED_ID      150103
+#define NEW_LINK      150104
+#define NEW_SYMLINK   150105
+#define REDIRECT_LINK 150106
+#define SEND_BY_EMAIL 150107
+#define LINK_HANDLING 150108
+#define EJECT_ID      150109
+#define PREVIEW_ID    150110
+#define COPY_CLIP_ID  150111
+#define MOVE_CLIP_ID  150112
+#define PASTE_CLIP_ID 150113
 
    // those will sometimes appear
-#define SERVICE_LIST_ID  200
+#define SERVICE_LIST_ID  150200
    //////////////////////////////////////////////////////////
    bool multipleSelections = false;
    // a quick hack to check if we've got more that one file selected
@@ -781,7 +804,7 @@ void ListPanel::popRightClickMenu( const QPoint &loc ) {
       // open in a new tab (if folder)
       if ( item->isDir() ) {
          popup.insertItem( i18n( "Open in a new tab" ), OPEN_TAB_ID );
-         popup.changeItem( OPEN_TAB_ID, krLoader->loadIcon( "favorites", KIcon::Panel ), i18n( "Open in a new tab" ) );
+         popup.changeItem( OPEN_TAB_ID, krLoader->loadIcon( "tab_new", KIcon::Panel ), i18n( "Open in a new tab" ) );
       }
       popup.insertSeparator();
    }
@@ -826,7 +849,7 @@ void ListPanel::popRightClickMenu( const QPoint &loc ) {
       popup.insertSeparator();
    }
    
-   popup.insertItem( i18n("Useractions"), new UserActionPopupMenu( func->files()->vfs_getFile( item->name() ).url() ) );
+   popup.insertItem( i18n("User Actions"), new UserActionPopupMenu( func->files()->vfs_getFile( item->name() ).url() ) );
    
    KFileItemList _items;
    _items.setAutoDelete( true );
@@ -1028,14 +1051,15 @@ void ListPanel::setFilter( KrViewProperties::FilterSpec f ) {
          case KrViewProperties::Custom :
          filterMask = KRSpWidgets::getMask( i18n( " Select Files " ) );
          // if the user canceled - quit
-         if ( filterMask == QString::null )
-            return ;
+         if ( filterMask.isNull() )
+            return;
          view->setFilterMask( filterMask );
          break;
          default:
          return ;
    }
    view->setFilter( f ); // do that in any case
+   func->files()->vfs_invalidate();
    func->refresh();
 }
 
@@ -1143,4 +1167,70 @@ void ListPanel::panelInactive() {
 	func->files()->vfs_enableRefresh(false);
 }
 
+void ListPanel::slotJobStarted(KIO::Job* job) {
+	// disable the parts of the panel we don't want touched
+	//static_cast<KrDetailedView*>(view)->setEnabled(false);
+	status->setEnabled(false);
+	origin->setEnabled(false);
+	cdRootButton->setEnabled(false);
+   cdHomeButton->setEnabled(false);
+   cdUpButton->setEnabled(false);
+   cdOtherButton->setEnabled(false);
+	popupBtn->setEnabled(false);
+	popup->setEnabled(false);
+   bookmarksButton->setEnabled(false);
+   historyButton->setEnabled(false);
+   syncBrowseButton->setEnabled(false);
+
+	// connect to the job interface to provide in-panel refresh notification
+	connect( job, SIGNAL( infoMessage( KIO::Job*, const QString & ) ),
+		SLOT( inlineRefreshInfoMessage( KIO::Job*, const QString & ) ) );
+	connect( job, SIGNAL( percent( KIO::Job*, unsigned long ) ),
+      SLOT( inlineRefreshPercent( KIO::Job*, unsigned long ) ) );		
+	connect(job,SIGNAL(result(KIO::Job*)),
+         this,SLOT(inlineRefreshListResult(KIO::Job*)));
+	connect(job,SIGNAL(canceled(KIO::Job*)),
+         this,SLOT(inlineRefreshListResult(KIO::Job*)));
+			
+	inlineRefreshJob = job;
+	
+	totals->setText(i18n(">> Reading..."));
+	inlineRefreshCancelButton->show();
+}
+
+void ListPanel::inlineRefreshCancel() {
+	if (inlineRefreshJob) {
+		inlineRefreshJob->kill(false);
+		inlineRefreshJob = 0;
+	}
+}
+
+void ListPanel::inlineRefreshPercent( KIO::Job*, unsigned long perc) {
+	QString msg = QString(">> %1: %2 % complete...").arg(i18n("Reading")).arg(perc);
+	totals->setText(msg);
+}
+
+void ListPanel::inlineRefreshInfoMessage( KIO::Job*, const QString &msg ) {
+	totals->setText(">> " + i18n("Reading: ") + msg);
+}
+
+void ListPanel::inlineRefreshListResult(KIO::Job*) {
+	inlineRefreshJob = 0;
+	// reenable everything
+	//static_cast<KrDetailedView*>(view)->setEnabled(true);
+	status->setEnabled(true);
+	origin->setEnabled(true);
+	cdRootButton->setEnabled(true);
+   cdHomeButton->setEnabled(true);
+   cdUpButton->setEnabled(true);
+   cdOtherButton->setEnabled(true);
+	popupBtn->setEnabled(true);
+	popup->setEnabled(true);
+   bookmarksButton->setEnabled(true);
+   historyButton->setEnabled(true);
+   syncBrowseButton->setEnabled(true);
+	
+	inlineRefreshCancelButton->hide();
+}
+
 #include "listpanel.moc"
