@@ -42,7 +42,7 @@ class ftp_vfs : public vfs{
 public:
 	// the constructor simply uses the inherited constructor
 	ftp_vfs(QObject* panel);
-	~ftp_vfs(){}
+	~ftp_vfs();
 
 	/// Copy a file to the vfs (physical).
 	virtual void vfs_addFiles(KURL::List *fileUrls,KIO::CopyJob::CopyMode mode,QObject* toNotify,QString dir = "");
@@ -56,10 +56,6 @@ public:
 	virtual void vfs_mkdir(const QString& name);
 	/// Rename file
 	virtual void vfs_rename(const QString& fileName,const QString& newName);
-	/// Calculate the amount of space occupied by a file or directory (recursive).
-	/// Not implemted (yet) in ftp_vfs
-	virtual void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop = 0);
-
 	/// Return the VFS working dir	
 	QString vfs_workingDir();
 	
@@ -75,11 +71,10 @@ public slots:
 	bool populateVfsList(const KURL& origin, bool showHidden);
 
 protected:
-	QDict<vfile>  vfs_files;    //< List of pointers to vfile.
+	vfileDict  vfs_files;    //< List of pointers to vfile.
 	KURL origin_backup;         //< used to backup the old URL when refreshing to a new one,
-
 	bool busy;
-	bool listError;
+	bool listError;     
 };
 
 #endif
