@@ -64,7 +64,7 @@ public:
 	/// Rename file
 	virtual void vfs_rename(const QString& fileName,const QString& newName);
 	/// Calculate the amount of space occupied by a file or directory (recursive).
-	virtual void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop = 0);
+	virtual void vfs_calcSpace(QString name ,KIO::filesize_t *totalSize,unsigned long *totalFiles,unsigned long *totalDirs, bool * stop);
 
 	/// return the VFS working dir
 	virtual QString vfs_workingDir() { return vfs_origin.path(-1); }
@@ -79,7 +79,7 @@ protected:
 	/// Re-reads files and stats and fills the vfile list
 	virtual bool populateVfsList(const KURL& origin, bool showHidden);
 
-	QDict<vfile>  vfs_files;     //< Dictionary of pointers to vfile	
+	vfileDict  vfs_files;     //< Dictionary of pointers to vfile	
 	QTimer refreshTimer;         //< Timer to exclude sudden refreshes
 	KDirWatch *watcher;          //< The internal dir watcher - use to detect changes in directories
 	vfile* vfileFromName(const QString& name,bool mimeTypeMagic);
