@@ -16,7 +16,7 @@
 #define HIDE  { _newTab->hide(); _tabbar->hide(); _closeTab->hide(); }
 
 PanelManager::PanelManager( QWidget *parent, bool left, ListPanel* &self, ListPanel* &other, ListPanel* &active ) :
-QWidget( parent ), _layout( 0 ), _left( left ), _self( self ), _other( other ), _active( active ) {
+QWidget( parent, "PanelManager" ), _layout( 0 ), _left( left ), _self( self ), _other( other ), _active( active ) {
    _layout = new QGridLayout( this, 1, 1 );
    _stack = new QWidgetStack( this );
 
@@ -24,16 +24,16 @@ QWidget( parent ), _layout( 0 ), _left( left ), _self( self ), _other( other ),
    _newTab = new QToolButton( this );
    _newTab->setFixedSize( 22, 22 );
    _newTab->setTextLabel( i18n( "Open a new tab in home" ) );
-   QImage im = krLoader->loadIcon( "favorites", KIcon::Panel ).convertToImage();
-   _newTab->setPixmap( im.scale( _newTab->height() - 5, _newTab->height() - 5 ) );
+   _newTab->setIconSet( SmallIcon( "tab_new" ) );
+   _newTab->adjustSize();	
    connect( _newTab, SIGNAL( clicked() ), this, SLOT( slotNewTab() ) );
 
    // close tab button
    _closeTab = new QToolButton( this );
    _closeTab->setFixedSize( 22, 22 );
    _closeTab->setTextLabel( i18n( "Close current tab" ) );
-   im = krLoader->loadIcon( "cancel", KIcon::Panel ).convertToImage();
-   _closeTab->setPixmap( im.scale( _closeTab->height() - 5, _closeTab->height() - 5 ) );
+   _closeTab->setIconSet( SmallIcon( "tab_remove" ) );
+   _closeTab->adjustSize();   
    connect( _closeTab, SIGNAL( clicked() ), this, SLOT( slotCloseTab() ) );
    _closeTab->setEnabled( false ); // disabled when there's only 1 tab
 
@@ -41,7 +41,7 @@ QWidget( parent ), _layout( 0 ), _left( left ), _self( self ), _other( other ),
    _tabbar = new PanelTabBar( this );
    connect( _tabbar, SIGNAL( changePanel( ListPanel* ) ), this, SLOT( slotChangePanel( ListPanel * ) ) );
    connect( _tabbar, SIGNAL( closeCurrentTab() ), this, SLOT( slotCloseTab() ) );
-   connect( _tabbar, SIGNAL( newTab( QString ) ), this, SLOT( slotNewTab( QString ) ) );
+   connect( _tabbar, SIGNAL( newTab( const KURL& ) ), this, SLOT( slotNewTab( const KURL& ) ) );
 
    _layout->addMultiCellWidget( _stack, 0, 0, 0, 2 );
    _layout->addWidget( _newTab, 1, 0 );
@@ -50,7 +50,12 @@ QWidget( parent ), _layout( 0 ), _left( left ), _self( self ), _other( other ),
 
    if ( HIDE_ON_SINGLE_TAB ) HIDE
       else SHOW
-      }
+		
+#ifdef __KJSEMBED__
+   // make this object available for scripting
+   krApp->js->addObject( this, "PanelManager" );
+#endif
+}
 
 void PanelManager::slotChangePanel( ListPanel *p ) {
    _self = p;
@@ -83,17 +88,17 @@ ListPanel* PanelManager::createPanel( bool setCurrent ) {
    return p;
 }
 
-void PanelManager::startPanel( ListPanel *panel, QString path ) {
+void PanelManager::startPanel( ListPanel *panel, const KURL& path ) {
    panel->start( path );
 }
 
-void PanelManager::saveSettings( KConfig *config, const QString& key ) {
+void PanelManager::saveSettings( KConfig *config, const QString& key, bool localOnly ) {
    QStringList l;
    int i=0, cnt=0;
    while (cnt < _tabbar->count()) {
       PanelTab *t = dynamic_cast<PanelTab*>(_tabbar->tabAt(i));
       if (t && t->panel) {
-         l << t->panel->realPath;
+         l << ( localOnly ? t->panel->realPath() : t->panel->virtualPath().prettyURL(0, KURL::StripFileProtocol ) );
          ++cnt;
       }
       ++i;
@@ -115,7 +120,8 @@ void PanelManager::loadSettings( KConfig *config, const QString& key ) {
       {
          t->panel->otherPanel = _other;
          _other->otherPanel = t->panel;
-         t->panel->func->openUrl( vfs::fromPathOrURL( l[ i ] ) );
+         t->panel->func->files()->vfs_enableRefresh( true );
+         t->panel->func->immediateOpenUrl( vfs::fromPathOrURL( l[ i ] ) );
       }
       ++i;
    }
@@ -124,14 +130,10 @@ void PanelManager::loadSettings( KConfig *config, const QString& key ) {
      slotCloseTab( --totalTabs );
       
    for(; i < (int)l.count(); i++ )
-     slotNewTab( l[i], false );
+     slotNewTab( vfs::fromPathOrURL(l[i]), false );
 }
 
-void PanelManager::slotNewTab() {
-   slotNewTab( QDir::home().absPath() );
-}
-
-void PanelManager::slotNewTab( QString path, bool setCurrent ) {
+void PanelManager::slotNewTab(const KURL& url, bool setCurrent) {
    ListPanel *p = createPanel( setCurrent );   
    // update left/right pointers
    p->otherPanel = _other;
@@ -140,7 +142,11 @@ void PanelManager::slotNewTab( QString path, bool setCurrent ) {
      _self = p;
      _other->otherPanel = _self;
    }
-   startPanel( p, path );
+   startPanel( p, url );
+}
+
+void PanelManager::slotNewTab() {
+   slotNewTab( QDir::home().absPath() );
 }
 
 void PanelManager::slotCloseTab() {
@@ -229,7 +235,7 @@ void PanelManager::setCurrentTab( int panelIndex )
   _stack->raiseWidget( _self );
 }
 
-void PanelManager::recreatePanels() {
+void PanelManager::slotRecreatePanels() {
    int actTab = activeTab();
    
    for( int i = 0; i != _tabbar->count(); i++ )
@@ -249,7 +255,7 @@ void PanelManager::recreatePanels() {
      if( _other->otherPanel == oldPanel )
        _other->otherPanel = newPanel;         
      updatedPanel->panel = newPanel;
-     newPanel->start( oldPanel->virtualPath );          
+     newPanel->start( oldPanel->virtualPath(), true );          
      delete oldPanel;
    
      _tabbar->updateTab( newPanel );
