@@ -32,17 +32,13 @@ class PanelManager: public QWidget {
      * Called once by KrusaderView to start the first panel. Subsequent called are done internally
      * Only starts the VFS inside the panel, you must first use createPanel() !
      */
-    void startPanel(ListPanel *panel, QString path);
-    /**
-     * Called by Konfigurator to recreate the panels after changing the configuration
-     */
-    void recreatePanels();
+    void startPanel(ListPanel *panel, const KURL& path);
     /**
      * Swaps the left / right directions of the panel
      */
     void swapPanels()             {_left = !_left;}
     
-    void saveSettings(KConfig *config, const QString& key);
+    void saveSettings(KConfig *config, const QString& key, bool localOnly = true );
     void loadSettings(KConfig *config, const QString& key);
     int  activeTab();
     void setActiveTab( int );
@@ -53,12 +49,13 @@ class PanelManager: public QWidget {
      * Called externally to start a new tab. Example of usage would be the "open in a new tab"
      * action, from the context-menu.
      */
-    void slotNewTab(QString path, bool setCurrent = true );
+    void slotNewTab(const KURL& url, bool setCurrent = true );
     void slotNewTab();
     void slotNextTab();
     void slotPreviousTab();	 
     void slotCloseTab();
     void slotCloseTab( int index );
+    void slotRecreatePanels();
 
   protected slots:
     void slotChangePanel(ListPanel *p);
